#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright 2012 Liricus SRL <info@liricus.com.ar>

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Fra


#===============================================================================
# DOCS
#===============================================================================

"""Utilities for send mail

"""

#===============================================================================
# IMPORTS
#===============================================================================

import string
import datetime

import flask_mail

from socialframe_server import core
from socialframe_server import settings


#===============================================================================
# FUNCTIONS
#===============================================================================

def send_mail(template, user, langs, data):    
    mail_dict = template[settings.DEFAULT_LANG]
    for lang in langs:
        if lang in template:
            mail_dict = template[lang]
            break
    
    now = datetime.datetime.now()
    subject = string.Template(mail_dict["subject"]).safe_substitute({
        "fname": user.fname,
        "lname": user.lname,
        "to": user.email,
        "from": settings.DEFAULT_MAIL_SENDER,
        "date": now.strftime(settings.DATE_FORMAT),
        "time": now.strftime("%H:%M:%S.%f"),
        "app": settings.APP_NAME,
        "data": data
    })
    body = string.Template(mail_dict["body"]).safe_substitute({
        "fname": user.fname,
        "lname": user.lname,
        "to": user.email,
        "from": settings.DEFAULT_MAIL_SENDER,
        "date": now.strftime(settings.DATE_FORMAT),
        "time": now.strftime("%H:%M:%S.%f"),
        "app": settings.APP_NAME,
        "data": data
    })
    msg = flask_mail.Message(subject, body=body, recipients=[user.email])
    core.APP_MAIL.send(msg)
    
    
#===============================================================================
# MAIN
#===============================================================================

if __name__ == "__main__":
    print(__doc__)
